@@ -4,7 +4,6 @@ import json
 import requests
 import aiohttp
 import asyncio
-import warnings
 
 
 class DiscordHandler(logging.Handler):
@@ -41,7 +40,7 @@ class DiscordHandler(logging.Handler):
         '''
         r = requests.get(url)
         if r.status_code != 200:
-            warnings.warn(f'Error establishing connection to webhook, URL returned a {r.status_code}')
+            raise Exception(f'Error establishing connection to webhook, URL returned a {r.status_code}')
             self._invalidURL = True
         return
 
@@ -88,7 +87,6 @@ class DiscordHandler(logging.Handler):
             headers = {'content-type': 'application/json'}
             logMsg = logMsg[:1900]
             data = json.dumps({'content': str(logMsg)})
-            async with aiohttp.request('POST', url, data=data, headers=headers) as _:
-                return
+            r = requests.post(url, headers=headers, data=data)
         except Exception:
             self.handleError(record)
